function [w1,Z,Pm] = TNewL(w,pmguess,L,params,A,cparams, T_li)

global nu n
% USED BY f_wages(y,w0)
% This program maps a wage vector into another, w1=T(w) where T is 
% Ti(w) = wi ( 1 +  nu*Zi(w)/Li ) 
% nu=1 (rate of convergence)
% It calls the function PmFunction.m.
% [w1,Z,pm] = T(w,y,pmguess)
%       w1 = T(w), 
%       Z is excess demand

% The function PmFunction calculates the price index for intermediate
% inputs when the cost for tradable goods is c = B * w^beta * Pm^1-beta


Pm = PmFunctionNew(w,pmguess,params,A,cparams, T_li);

k = cparams.k;
h = cparams.h;
theta = params.theta;
rho   = params.rho;
xi    = params.xi;
beta  =params.beta;
alpha =params.alpha;
B     = params.B;

c        = B* (w.^beta).* (Pm.^(1-beta));
c_matrix = (diag(c)*ones(n,n))';         % This matrix is nXn with repeated rows of the form: [c(1) c(2) ...c(n); c(1)...c(n);...]
T_cost   = c_matrix./k;          % This matrix is nXn of the form:                    [c(1)/k11 c(2)/k12 ...c(n)/k1n; c(1)/k21...c(n)/k2n;...]
MP_cost  = c_matrix'./h;         % This matrix is nXn of the form:                    [c(1)/h11 c(1)/h12 ...c(1)/h1n; c(2)/h21...c(2)/h2n;...]
tot      = (1-A)* MP_cost.^(1-rho) + A* T_cost.^(1-rho);            
Cin      = tot.^(1/(1-rho));
omega    = A*(T_cost.^(1-rho))./ tot;   

    pi_nil  = zeros(n,n,n);
    Cnil    = zeros(n,n,n);
    MPT     = zeros(n,n);
    sMCube  = zeros(n,n,n);
    ProdNorm = zeros(n,n,n);
    % The order of subscripts is (n,i,l = destination, origin, bridge)
for l = 1:n
    Cnil(:,:,l) = repmat(Cin(l,:),n,1) ./ repmat(k(:,l),1,n);                       %<-nikhil>
end

Prod = (Cnil.^(-1/theta)).*repmat(T_li,[1,1,n]);

MaxProd = max(Prod,[],3);
for l = 1:n;
   ProdNorm(:,:,l) = Prod(:,:,l)./MaxProd(:,:);
end
Psi_ni  = MaxProd .* sum(ProdNorm.^(1/xi),3).^xi;

Psi_n   = sum(Psi_ni,2);
Psi_n_matrix = diag(Psi_n)*ones(n,n);    % This matrix is nXn of the form: [Psi(1) Psi(1) ...Psi(1); Psi(2)...Psi(2);...; Psi(n)...Psi(n)]

s_ni   = Psi_ni./Psi_n_matrix;    % trade shares with national technologies

for l=1:n
    pi_nil(:,:,l) = (Prod(:,:,l) ./Psi_ni).^(1/xi);
    sMCube(:,:,l) =  s_ni.*pi_nil(:,:,l);
    MPT(l,:)      = sum(sMCube(:,:,l).*(diag(L.*w)*ones(n,n)),1)*(1-alpha)/beta;  
end

%sTMatrix = ProdV./Psi_n_matrix;
ALshares = sum(permute(sMCube,[1 3 2]),3); % + sTMatrix;

M_ni = ALshares.*(diag(L.*w)*ones(n,n))*(1-alpha)/beta + omega.*MPT; %+ sTMatrix;
D_in = M_ni./(diag(L.*w)*ones(n,n));
EX = sum(M_ni)' - diag(M_ni);                           % EX is a vector with total exports by country. Hence is sum over COLUMNS of the matrix Din_hat:
                                                        % EX(i) = sum(Din*Li*wi) - diag(Dii*Li*wi)
                                                        
IM = (w.*L).*(sum(D_in,2)- diag(D_in));                 % IM is a vector with total import shares by country. Hence is sum over ROWS of the matrix D_in --for n ~=i:
                                                        % IM(i) = sum(D_in)- diag(D_in)                                                        
Z  = (EX - IM)./w;
w1 = w.*(1 + nu*Z./L);
