function [w1,Z,Pm] = TNewTrade(w,pmguess,cparams,params,T_li,L)

global nu I

k = cparams.k;
B = params.B;
beta = params.beta;
theta = params.theta;
alpha = params.alpha;


% USED BY f_wages(y,w0)
% This program maps a wage vector into another, w1=T(w) where T is 
% Ti(w) = wi ( 1 +  nu*Zi(w)/Li ) 
% nu=1 (rate of convergence)
% It calls the function PmFunction.m.
% [w1,Z,pm] = T(w,y,pmguess)
%       w1 = T(w), 
%       Z is excess demand

% The function PmFunction calculates the price index for intermediate
% inputs when the cost for tradable goods is c = B * w^beta * Pm^1-beta

Pm = PmFunctionNewTrade(w,pmguess,cparams,params,T_li);

c        = B* (w.^beta).* (Pm.^(1-beta));
c_matrix = (diag(c)*I)';         % This matrix is nXn with repeated rows of the form: [c(1) c(2) ...c(n); c(1)...c(n);...]
T_cost   = c_matrix./k;          % This matrix is nXn of the form:                    [c(1)/k11 c(2)/k12 ...c(n)/k1n; c(1)/k21...c(n)/k2n;...]

Psi_ni  = (diag(diag(T_li))*I)'.*(T_cost.^(-1/theta));

Psi_n   = sum(Psi_ni,2);
Psi_n_matrix = diag(Psi_n)*I;    % This matrix is nXn of the form: [Psi(1) Psi(1) ...Psi(1); Psi(2)...Psi(2);...; Psi(n)...Psi(n)]

s_ni   = Psi_ni./Psi_n_matrix;    % trade shares with national technologies

M_ni = s_ni.*(diag(L.*w)*I)*(1-alpha)/beta;
D_in = M_ni./(diag(L.*w)*I);
EX = sum(M_ni)' - diag(M_ni);                           % EX is a vector with total exports by country. Hence is sum over COLUMNS of the matrix Din_hat:
                                                        % EX(i) = sum(Din*Li*wi) - diag(Dii*Li*wi)
                                                        
IM = (w.*L).*(sum(D_in,2)- diag(D_in));                 % IM is a vector with total import shares by country. Hence is sum over ROWS of the matrix D_in --for n ~=i:
                                                        % IM(i) = sum(D_in)- diag(D_in) 
                                                        
Z  = (EX - IM)./w;
w1 = w.*(1 + nu*Z./L);
